@@ -64,7 +64,9 @@ def write_wtstdataset_from_raw_data(
     preprocess: WTSeriesPreProcess,
     merge_pairs: bool,
     n_category: int,
-    standardize: bool
+    standardize: bool,
+    selected_columns: List[str] = [],
+    unselected_columns: List[str] = []
 ):
 
     dataset = WTSTrainingDataset(
@@ -76,12 +78,6 @@ def write_wtstdataset_from_raw_data(
     )
 
     list_to_std: Set[str] = set()
-    if standardize:
-        list_to_std.add("open")
-        list_to_std.add("close")
-        list_to_std.add("low")
-        list_to_std.add("high")
-        list_to_std.add("volume")
     rawdata_set: Dict[str, Dict[str, pd.DataFrame]] = {}
     for pair in pairs:
         for tf in timeframes:
@@ -95,11 +91,29 @@ def write_wtstdataset_from_raw_data(
                     dropna=True,
                     standardize=standardize,
                     list_to_std=list_to_std)
+
+            # set selected columns and set features of the dataset
+            if not selected_columns:
+                selected_columns = list(
+                    set(list(raw_data.columns)) - set(unselected_columns) - set([index_column])
+                )
+            if not dataset.features_has_been_set:
+                dataset.set_features(selected_columns)
+
             if tf not in rawdata_set:
                 rawdata_set[tf] = {pair: raw_data}
             else:
                 rawdata_set[tf][pair] = raw_data
 
+    if standardize:
+        list_to_std.add("open")
+        list_to_std.add("close")
+        list_to_std.add("low")
+        list_to_std.add("high")
+        list_to_std.add("volume")
+
+    list_to_std = list_to_std & set(selected_columns)
+
     if merge_pairs:
         for i, tf in enumerate(rawdata_set):
             data_to_add = merge_dict_of_dataframe(rawdata_set[tf], index_column=index_column)
